@@ -30,3 +30,12 @@ class App(Base):
                        .handle_operation()\
                        .get_output_streams()
     return streams
+
+  def call_component(self, name=None, component_id=None, outputs=None, output_format="replace"):
+    op = OperationHandler(self, Stream)
+    op = op.build_multilang_operation("component", name, component_id, self, None, outputs, output_format)\
+           .add_operation_properties_to_info("name", "type", "id", "output_format")
+    node = op.node()
+    streams = op.handle_operation()\
+                .get_output_streams()
+    return streams
